@@ -47,7 +47,7 @@ test_that("oadoi_fetch returns", {
 
 
   # some character matches
-  expect_match(h$oa_status, "bronze")
+  expect_match(h$oa_status, "closed")
   expect_match(h$journal_issn_l, "0001-8708")
   expect_match(a$published_date, "2016-08-09")
 
@@ -91,7 +91,7 @@ test_that("oadoi_fetch removes all types of whitespace", {
   skip_on_cran()
   dois <- c("10.1177/ 0042098012452322",
     "10.1038/ng.3260 ",
-    " 10.     7717/peerj.2323 
+    " 10.     7717/peerj.2323
       ")
   a <- expect_message(
     oadoi_fetch(dois, email = "najko.jahn@gmail.com")
